Method: Spore::Middleware#process_request
- Defined in:
- lib/spore/middleware.rb
#process_request(env) ⇒ Object
This is where your middleware can handle an incoming request before it’s executed (the env hash contains anything to build the query) if you want to halt the process of the request, return a Net::HTTP response object if you just want to alter the env hash, do it and return nil
32 33 |
# File 'lib/spore/middleware.rb', line 32 def process_request(env) end |